@@ -24,10 +24,10 @@ async def _read(stream, echo=True, color=None):
         if echo:
             if color:
                 for value in color, chunk, RESET:
-                    sys.stdout.buffer.write(value)
+                    sys.stderr.buffer.write(value)
             else:
-                sys.stdout.buffer.write(chunk)
-            sys.stdout.buffer.flush()
+                sys.stderr.buffer.write(chunk)
+            sys.stderr.buffer.flush()
 
     return buf.getvalue()
 
@@ -56,6 +56,9 @@ class Result:
     def __str__(self):
         return self.stdout.decode().strip()
 
+    def __iter__(self):
+        yield from str(self).splitlines()
+
     def _write(self, path, stream, mode):
         with open(path, mode) as f:
             log.info(f"Writing {stream} to {path}({mode})")
@@ -80,9 +83,7 @@ class Result:
         This directly connects the stdout left -> right like a shell pipeline
         so that commands run in parallel
         """
-        stdin = {'input': self.stdout}
-        # stdin = {'input': self.stdout} if self._waited else {'stdin': self._process.stdout}
-        return Command(*other._command, **(other._kwargs | stdin))
+        return Command(*other._command, **{**other._kwargs, 'stdin': io.BytesIO(self.stdout)})
 
 
 def _nonstriterable(value):
@@ -112,7 +113,7 @@ class Command:
         kwargs = self._kwargs | converted_kwargs
         log.warning(f"Executing: {cmd}")
         result = create_subprocess_exec(*map(str, cmd), **kwargs)
-        return Result(self, result)
+        return Result(self, result, echo=logging.root.level <= logging.INFO)
 
     def __getitem__(self, *args):
         return Command(*(self._command + [*args]), _env=self._env, **self._kwargs)
@@ -157,7 +158,7 @@ class _AushModule(ModuleType):
     __path__: list[str] = []
 
     def __getitem__(self, name):
-        return Command(name)
+        return Command(name.replace('_', '-'))
 
     __getattr__ = __getitem__
 
